// Schnittstelle zur Anzeige eines NOKIA 3310 (PCD8544)
// leichte Vernderungen fr NOKIA 3410 (PCF8812) in geschweiften Klammern
// Die Port-Richtungsregister mssen von der Hauptanwendung gesetzt werden

#define _SCLK 	PORTAbits.RA3  	//fr Hardware SPI-Modulo berflssig
#define _SDO 	PORTAbits.RA1   //dito
#define _DC 	PORTBbits.RB4
#define _SCE 	PORTBbits.RB5
#define _RESET 	PORTAbits.RA2 	//!!ber Schieberegister U9

#include 	<spi.h>	
#include	<delays.h>

#pragma idata Sektion0
const unsigned char XAdrSatz3310=0b10000000;
const unsigned char YAdrSatz3310=0b01000000;

#define NOKIA3310  //fr NOKIA3410 diesen Wert ndern
#ifdef NOKIA3310   //bzw. PCD8544
const unsigned char LCDErwFktSatz	=0x21;	 	// Einschalten, horizontale Adressierung
const unsigned char LCDUbEinst		=0xC2;		// Bit 0=1 --> Extended Instruction Set
const unsigned char LCDTempKoeff	=0x13;	 	// Ub einstellen
const unsigned char LCDFktSatz		=0x20;		// Temp.-Koeff.
const unsigned char LCDNormModus	=0x09;		// LCD im Normalen Modus
const unsigned char LCDInverModus	=0x0F;		// LCD im inversen Modus
#endif
#ifdef NOKIA3410// bzw. PCF8812
const unsigned char LCDErwFktSatz	=0x21;	 	// Einschalten, horizontale Adressierung
const unsigned char LCDUbEinst		=0x11;		// Bit 0=1 --> Extended Instruction Set
const unsigned char LCDTempKoeff	=0x9C;	 	// Ub einstellen
const unsigned char LCDFktSatz		=0x20;		// Temp.-Koeff.
const unsigned char LCDNormModus	=0x0C;		// LCD im Normalen Modus
const unsigned char LCDInverModus	=0x0F;		// LCD im inversen Modus
#endif

// Zeichensatzdefinition
// Zeichen 0..9F
// 795 Byte Programmspeicher
// Aufteilung auf 4 Arrays notwendig, da maximale Arraygre=256
// !!! Bei nderung der Zeichenanzahl MaxASCIICode UND Gre der letzten Tabelle ndern

const unsigned char MaxASCIIZeichen=0x9f;		 		// Anzahl definierter Zeichen

#pragma idata Sektion1
rom unsigned char Zeichentabelle0[51][5]={
	{ 0x5C,0x62,0x02,0x62,0x5C}, // ASCII-Code 0x00 (0)
	{ 0x12,0x19,0x15,0x12,0x00}, // ASCII-Code 0x01 (1)
	{ 0x11,0x15,0x15,0x0A,0x00}, // ASCII-Code 0x02 (2)
	{ 0x7F,0x00,0x00,0x00,0x00}, // ASCII-Code 0x03 (3)
	{ 0x7F,0x7F,0x00,0x00,0x00}, // ASCII-Code 0x04 (4)
	{ 0x7F,0x7F,0x7F,0x00,0x00}, // ASCII-Code 0x05 (5)
	{ 0x7F,0x7F,0x7F,0x7F,0x00}, // ASCII-Code 0x06 (6)
	{ 0x7F,0x7F,0x7F,0x7F,0x7F}, // ASCII-Code 0x07 (7)
	{ 0x80,0x80,0x80,0x80,0x80}, // ASCII-Code 0x08 (8)
	{ 0xC0,0xC0,0xC0,0xC0,0xC0}, // ASCII-Code 0x09 (9)
	{ 0xE0,0xE0,0xE0,0xE0,0xE0}, // ASCII-Code 0x0A (10)
	{ 0xF0,0xF0,0xF0,0xF0,0xF0}, // ASCII-Code 0x0B (11)
	{ 0xF8,0xF8,0xF8,0xF8,0xF8}, // ASCII-Code 0x0C (12)
	{ 0xFC,0xFC,0xFC,0xFC,0xFC}, // ASCII-Code 0x0D (13)
	{ 0xFE,0xFE,0xFE,0xFE,0xFE}, // ASCII-Code 0x0E (14)
	{ 0xFF,0xFF,0xFF,0xFF,0xFF}, // ASCII-Code 0x0F (15)
	{ 0x00,0x7F,0x3E,0x1C,0x08}, // ASCII-Code 0x10 (16)
	{ 0x08,0x1C,0x3E,0x7F,0x00}, // ASCII-Code 0x11 (17)
	{ 0x06,0x05,0x00,0x06,0x05}, // ASCII-Code 0x12 (18)
	{ 0x05,0x03,0x00,0x05,0x03}, // ASCII-Code 0x13 (19)
	{ 0x44,0x66,0x77,0x66,0x44}, // ASCII-Code 0x14 (20)
	{ 0x11,0x33,0x77,0x33,0x11}, // ASCII-Code 0x15 (21)
	{ 0x1C,0x3E,0x3E,0x3E,0x1C}, // ASCII-Code 0x16 (22)
	{ 0x10,0x38,0x54,0x10,0x1F}, // ASCII-Code 0x17 (23)
	{ 0x04,0x02,0x7F,0x02,0x04}, // ASCII-Code 0x18 (24)
	{ 0x10,0x20,0x7F,0x20,0x10}, // ASCII-Code 0x19 (25)
	{ 0x08,0x08,0x2A,0x1C,0x08}, // ASCII-Code 0x1A (26)
	{ 0x08,0x1C,0x2A,0x08,0x08}, // ASCII-Code 0x1B (27)
	{ 0x40,0x44,0x4A,0x51,0x40}, // ASCII-Code 0x1C (28)
	{ 0x40,0x51,0x4A,0x44,0x40}, // ASCII-Code 0x1D (29)
	{ 0x20,0x38,0x3E,0x38,0x20}, // ASCII-Code 0x1E (30)
	{ 0x02,0x0E,0x3E,0x0E,0x02}, // ASCII-Code 0x1F (31)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x20 (32)
	{ 0x00,0x00,0x4F,0x00,0x00}, // ASCII-Code 0x21 (33)
	{ 0x00,0x07,0x00,0x07,0x00}, // ASCII-Code 0x22 (34)
	{ 0x14,0x7F,0x14,0x7F,0x14}, // ASCII-Code 0x23 (35)
	{ 0x24,0x2A,0x7F,0x2A,0x12}, // ASCII-Code 0x24 (36)
	{ 0x23,0x13,0x08,0x64,0x62}, // ASCII-Code 0x25 (37)
	{ 0x36,0x49,0x55,0x22,0x50}, // ASCII-Code 0x26 (38)
	{ 0x00,0x05,0x03,0x00,0x00}, // ASCII-Code 0x27 (39)
	{ 0x00,0x1C,0x22,0x41,0x00}, // ASCII-Code 0x28 (40)
	{ 0x00,0x41,0x22,0x1C,0x00}, // ASCII-Code 0x29 (41)
	{ 0x14,0x08,0x3E,0x08,0x14}, // ASCII-Code 0x2A (42)
	{ 0x08,0x08,0x3E,0x08,0x08}, // ASCII-Code 0x2B (43)
	{ 0x00,0x50,0x30,0x00,0x00}, // ASCII-Code 0x2C (44)
	{ 0x08,0x08,0x08,0x08,0x08}, // ASCII-Code 0x2D (45)
	{ 0x00,0x60,0x60,0x00,0x00}, // ASCII-Code 0x2E (46)
	{ 0x20,0x10,0x08,0x04,0x02}, // ASCII-Code 0x2F (47)
	{ 0x3E,0x51,0x49,0x45,0x3E}, // ASCII-Code 0x30 (48)
	{ 0x00,0x42,0x7F,0x40,0x00}, // ASCII-Code 0x31 (49)
	{ 0x42,0x61,0x51,0x49,0x46}, // ASCII-Code 0x32 (50)
	};
rom unsigned char Zeichentabelle1[51][5]={
	{ 0x21,0x41,0x45,0x4B,0x31}, // ASCII-Code 0x33 (51)
	{ 0x18,0x14,0x12,0x7F,0x10}, // ASCII-Code 0x34 (52)
	{ 0x27,0x45,0x45,0x45,0x39}, // ASCII-Code 0x35 (53)
	{ 0x3C,0x4A,0x49,0x49,0x30}, // ASCII-Code 0x36 (54)
	{ 0x01,0x01,0x79,0x05,0x03}, // ASCII-Code 0x37 (55)
	{ 0x36,0x49,0x49,0x49,0x36}, // ASCII-Code 0x38 (56)
	{ 0x06,0x49,0x49,0x29,0x1E}, // ASCII-Code 0x39 (57)
	{ 0x00,0x36,0x36,0x00,0x00}, // ASCII-Code 0x3A (58)
	{ 0x00,0x56,0x36,0x00,0x00}, // ASCII-Code 0x3B (59)
	{ 0x08,0x14,0x22,0x41,0x00}, // ASCII-Code 0x3C (60)
	{ 0x14,0x14,0x14,0x14,0x14}, // ASCII-Code 0x3D (61)
	{ 0x00,0x41,0x22,0x14,0x08}, // ASCII-Code 0x3E (62)
	{ 0x02,0x01,0x51,0x09,0x06}, // ASCII-Code 0x3F (63)
	{ 0x32,0x79,0x79,0x41,0x3E}, // ASCII-Code 0x40 (64)
	{ 0x7E,0x11,0x11,0x11,0x7E}, // ASCII-Code 0x41 (65)
	{ 0x41,0x7F,0x49,0x49,0x36}, // ASCII-Code 0x42 (66)
	{ 0x3E,0x41,0x41,0x41,0x22}, // ASCII-Code 0x43 (67)
	{ 0x41,0x7F,0x41,0x41,0x3E}, // ASCII-Code 0x44 (68)
	{ 0x7F,0x49,0x49,0x49,0x49}, // ASCII-Code 0x45 (69)
	{ 0x7F,0x09,0x09,0x09,0x01}, // ASCII-Code 0x46 (70)
	{ 0x3E,0x41,0x41,0x49,0x7A}, // ASCII-Code 0x47 (71)
	{ 0x7F,0x08,0x08,0x08,0x7F}, // ASCII-Code 0x48 (72)
	{ 0x00,0x41,0x7F,0x41,0x00}, // ASCII-Code 0x49 (73)
	{ 0x20,0x40,0x41,0x3F,0x01}, // ASCII-Code 0x4A (74)
	{ 0x7F,0x08,0x14,0x22,0x41}, // ASCII-Code 0x4B (75)
	{ 0x7F,0x40,0x40,0x40,0x40}, // ASCII-Code 0x4C (76)
	{ 0x7F,0x02,0x06,0x02,0x7F}, // ASCII-Code 0x4D (77)
	{ 0x7F,0x06,0x08,0x30,0x7F}, // ASCII-Code 0x4E (78)
	{ 0x3E,0x41,0x41,0x41,0x3E}, // ASCII-Code 0x4F (79)
	{ 0x7F,0x09,0x09,0x09,0x06}, // ASCII-Code 0x50 (80)
	{ 0x3E,0x41,0x51,0x21,0x5E}, // ASCII-Code 0x51 (81)
	{ 0x7F,0x09,0x19,0x29,0x46}, // ASCII-Code 0x52 (82)
	{ 0x26,0x49,0x49,0x49,0x32}, // ASCII-Code 0x53 (83)
	{ 0x01,0x01,0x7F,0x01,0x01}, // ASCII-Code 0x54 (84)
	{ 0x3F,0x40,0x40,0x40,0x3F}, // ASCII-Code 0x55 (85)
	{ 0x1F,0x20,0x40,0x20,0x1F}, // ASCII-Code 0x56 (86)
	{ 0x7F,0x20,0x18,0x20,0x7F}, // ASCII-Code 0x57 (87)
	{ 0x63,0x14,0x08,0x14,0x63}, // ASCII-Code 0x58 (88)
	{ 0x07,0x08,0x70,0x08,0x07}, // ASCII-Code 0x59 (89)
	{ 0x61,0x51,0x49,0x45,0x43}, // ASCII-Code 0x5A (90)
	{ 0x00,0x7F,0x41,0x41,0x00}, // ASCII-Code 0x5B (91)
	{ 0x02,0x04,0x08,0x10,0x20}, // ASCII-Code 0x5C (92)
	{ 0x00,0x41,0x41,0x7F,0x00}, // ASCII-Code 0x5D (93)
	{ 0x04,0x02,0x01,0x02,0x04}, // ASCII-Code 0x5E (94)
	{ 0x40,0x40,0x40,0x40,0x40}, // ASCII-Code 0x5F (95)
	{ 0x01,0x02,0x04,0x00,0x00}, // ASCII-Code 0x60 (96)
	{ 0x20,0x54,0x54,0x54,0x78}, // ASCII-Code 0x61 (97)
	{ 0x7F,0x48,0x44,0x44,0x38}, // ASCII-Code 0x62 (98)
	{ 0x38,0x44,0x44,0x44,0x28}, // ASCII-Code 0x63 (99)
	{ 0x38,0x44,0x44,0x48,0x7F}, // ASCII-Code 0x64 (100)
	{ 0x38,0x54,0x54,0x54,0x18}, // ASCII-Code 0x65 (101)
	};

rom unsigned char Zeichentabelle2[51][5]={
	{ 0x00,0x08,0x7E,0x09,0x02}, // ASCII-Code 0x66 (102)
	{ 0x18,0xA4,0xA4,0x98,0x7C}, // ASCII-Code 0x67 (103)
	{ 0x7F,0x08,0x04,0x04,0x78}, // ASCII-Code 0x68 (104)
	{ 0x00,0x44,0x7D,0x40,0x00}, // ASCII-Code 0x69 (105)
	{ 0x40,0x80,0x84,0x7D,0x00}, // ASCII-Code 0x6A (106)
	{ 0x00,0x7F,0x10,0x28,0x44}, // ASCII-Code 0x6B (107)
	{ 0x00,0x41,0x7F,0x40,0x00}, // ASCII-Code 0x6C (108)
	{ 0x7C,0x04,0x78,0x04,0x78}, // ASCII-Code 0x6D (109)
	{ 0x7C,0x08,0x04,0x04,0x78}, // ASCII-Code 0x6E (110)
	{ 0x38,0x44,0x44,0x44,0x38}, // ASCII-Code 0x6F (111)
	{ 0xFC,0x18,0x24,0x24,0x18}, // ASCII-Code 0x70 (112)
	{ 0x18,0x24,0x24,0x18,0xFC}, // ASCII-Code 0x71 (113)
	{ 0x7C,0x08,0x04,0x04,0x08}, // ASCII-Code 0x72 (114)
	{ 0x58,0x54,0x54,0x54,0x64}, // ASCII-Code 0x73 (115)
	{ 0x04,0x3F,0x44,0x40,0x20}, // ASCII-Code 0x74 (116)
	{ 0x3C,0x40,0x40,0x3C,0x40}, // ASCII-Code 0x75 (117)
	{ 0x1C,0x20,0x40,0x20,0x1C}, // ASCII-Code 0x76 (118)
	{ 0x3C,0x40,0x30,0x40,0x3C}, // ASCII-Code 0x77 (119)
	{ 0x44,0x28,0x10,0x28,0x44}, // ASCII-Code 0x78 (120)
	{ 0x1C,0xA0,0xA0,0x90,0x7C}, // ASCII-Code 0x79 (121)
	{ 0x44,0x64,0x54,0x4C,0x44}, // ASCII-Code 0x7A (122)
	{ 0x00,0x08,0x36,0x41,0x00}, // ASCII-Code 0x7B (123)
	{ 0x00,0x00,0x7F,0x00,0x00}, // ASCII-Code 0x7C (124)
	{ 0x00,0x41,0x36,0x08,0x00}, // ASCII-Code 0x7D (125)
	{ 0x10,0x08,0x08,0x10,0x08}, // ASCII-Code 0x7E (126)
	{ 0x00,0x06,0x09,0x09,0x06}, // ASCII-Code 0x7F (127)
	{ 0x30,0x28,0x24,0x28,0x30}, // ASCII-Code 0x80 (128)
	{ 0x38,0x42,0x40,0x3A,0x40}, // ASCII-Code 0x81 (129)
	{ 0x03,0x03,0x38,0x44,0x44}, // ASCII-Code 0x82 (130)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x83 (131)
	{ 0x20,0x55,0x54,0x55,0x78}, // ASCII-Code 0x84 (132)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x85 (133)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x86 (134)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x87 (135)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x88 (136)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x89 (137)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x8A (138)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x8B (139)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x8C (140)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x8D (141)
	{ 0x78,0x25,0x24,0x25,0x78}, // ASCII-Code 0x8E (142)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x8F (143)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x90 (144)
	{ 0x24,0x54,0x7C,0x54,0x58}, // ASCII-Code 0x91 (145)
	{ 0x7E,0x11,0x7F,0x49,0x41}, // ASCII-Code 0x92 (146)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x93 (147)
	{ 0x30,0x4A,0x48,0x4A,0x30}, // ASCII-Code 0x94 (148)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x95 (149)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x96 (150)
	{ 0x00,0x00,0x00,0x00,0x00}, // ASCII-Code 0x97 (151)
	{ 0x1C,0x36,0x55,0x55,0x41}, // ASCII-Code 0x98 (152)
	};

rom unsigned char Zeichentabelle3[7][5]={
	{ 0x38,0x45,0x44,0x45,0x38}, // ASCII-Code 0x99 (153)
	{ 0x38,0x42,0x40,0x42,0x38}, // ASCII-Code 0x9A (154)
	{ 0x1C,0x22,0x7F,0x22,0x14}, // ASCII-Code 0x9B (155)
	{ 0x68,0x7E,0x29,0x41,0x22}, // ASCII-Code 0x9C (156)
	{ 0x29,0x2A,0x7C,0x2A,0x29}, // ASCII-Code 0x9D (157)
	{ 0x77,0x05,0x12,0x7C,0x50}, // ASCII-Code 0x9E (158)
	{ 0x48,0x7E,0x49,0x01,0x02}, // ASCII-Code 0x9F (159)
	};
#pragma idata

#pragma code


void SendeDaten(unsigned char* Puffer,unsigned char Anzahl) 	//Datenpuffer zur Anzeige senden
{ 														//Hardware-Routine
	unsigned char iByte;								//Das SPI-Modul muss richtig konfiguriert sein
  	unsigned char i;									//d.h. OpenSPI(..), TRISA/B=...
  	_SCE=0;												//Anzeige einschalten
  	for (iByte=0;iByte<Anzahl;++iByte)
	{
	 WriteSPI(Puffer[iByte]);
	 while (!PIR1bits.SSPIF);							//Warten, bis versendet *dies knnte man viel besser	
	}													//mit Interrupts hndeln
  	_SCE=1;												//Anzeige aus
}

/*
void SendeDaten(unsigned char* Puffer,unsigned char Anzahl) 	//Datenpuffer zur Anzeige senden
{ 														//Software-Ausgabe
	unsigned char iByte;								//Die Ausgnge mssen richtig konfiguriert sein
	unsigned char BytePuffer;							//d.h. die zu SDO und SCLK gehrenden PORTA/B bzw. TRISA/B
  	unsigned char i;
  	_SCE=0;												//Anzeige einschalten
  	for (iByte=0;iByte<Anzahl;++iByte)
	{
	 BytePuffer=Puffer[iByte]; 
	 	for (i=0;i<=7;++i)
  		{
		 _SCLK=0;
		 _SDO=!!(BytePuffer & 0b10000000);				//Bits einzeln heraustakten
		 _SCLK=1;		  								//doppeltes Nicht um Boolean-Typ zu erzwingen
		 BytePuffer<<=1;								//Bits rotieren
  		}
	}
  	_SCE=1;												//Anzeige aus
}
*/

void InitAnzeige()										//Anzeige initialisieren
{ 
	unsigned char InitDaten[5];	
  	_RESET=0;											//!!Anzeige zurcksetzen
	Delay10TCY();										//zwei M warten
	_RESET=1;
	Delay10TCY();
  	InitDaten[0]=LCDErwFktSatz;							//erweiterer Befehlssatz
  	InitDaten[1]=LCDUbEinst;							//Betriebsspannung
  	InitDaten[2]=LCDTempKoeff;							//Bias-Spannung bzw. Temp.Koeff.
  	InitDaten[3]=LCDFktSatz;							//Befehls-Basissatz
  	InitDaten[4]=LCDNormModus;							//normal mode
  	_DC=0;												//sende Befehl
  	SendeDaten(InitDaten,5);
}

void PosZeichenkursor(unsigned char X,unsigned char Y)	//Kursor-Position fr Textausgabe
{ 														//Grenzen: 0<=X<=13 und 0<=Y<=5 !
	unsigned char Kursordaten[2];						//Sendepuffer zur Anzeige
  	X*=6;
  	Kursordaten[0]=X|XAdrSatz3310;						//nach LCD-Befehlssatz X-Adresse bilden
  	Kursordaten[1]=Y|YAdrSatz3310;						//nach LCD-Befehlssatz Y-Adresse bilden
  	_DC=0;												//sende Befehl
	SendeDaten(Kursordaten,2);
}

void PosGrafikkursor(unsigned char X, unsigned char Y)	//Kursor-Position fr Grafik-Ausgabe
{ 														//Grenzen: 0<=X<=83, 0<=Y<=5 !
	unsigned char Kursordaten[2];						//Sendepuffer zur Anzeige
	Kursordaten[0]=X|XAdrSatz3310;						//nach LCD-Befehlssatz X-Adresse bilden
	Kursordaten[1]=Y|YAdrSatz3310;						//nach LCD-Befehlssatz Y-Adresse bilden
	_DC=0;												//Befehls-Modus
	SendeDaten(Kursordaten,2);
}

void LoescheAnzeige()									//Anzeigedaten lschen
{ 
	unsigned char i;
  	unsigned char Daten[12]={0,0,0,0,0,0,0,0,0,0,0,0};
  	PosGrafikkursor(0,0);								//Kursor in der Anzeige auf 0,0
  	_DC=1;												//Daten-Modus
	for (i=0;i<=41;++i)									// 12*42=504 Byte Anzeigespeicher
   	SendeDaten(Daten,12);								// 12 Byte=2 Zeichen auf einmal lschen
}

void AnzeigeModus(unsigned char M)						//Anzeige-Modus einstellen
{ 														//M=0 positiv, M=1 invertiert
	unsigned char Daten[2];
	if (M!=0)
	 Daten[0]=LCDInverModus;
  	else
     Daten[0]=LCDNormModus;
	_DC=0;												//Befehls-Modus
  	SendeDaten(Daten,1);
}

void SendeZeichen(unsigned char Zeichen)	
{ 
	unsigned char Streifen;
  	unsigned char Puffer[6];
	unsigned char y,z;
	if (Zeichen>MaxASCIIZeichen) return;		//grer als Maximalanzahl?
  	z=(Zeichen)/51;								//Tabelle bestimmen  
  	y=Zeichen%51;
 												//Divissionrest
  	switch(z)
  	{ 	
		case 0: 
			for (Streifen=0;Streifen<=4;++Streifen)		//jedes Zeichen besteht aus 5 Byte bzw. Streifen
  			Puffer[Streifen]=Zeichentabelle0[y][Streifen]; 
			break;
		case 1: 
			for (Streifen=0;Streifen<=4;++Streifen)		//jedes Zeichen besteht aus 5 Byte bzw. Streifen
  			Puffer[Streifen]=Zeichentabelle1[y][Streifen]; 
			break;
		case 2: 
			for (Streifen=0;Streifen<=4;++Streifen)		//jedes Zeichen besteht aus 5 Byte bzw. Streifen
  			Puffer[Streifen]=Zeichentabelle2[y][Streifen]; 
			break;
		case 3: 
			for (Streifen=0;Streifen<=4;++Streifen)		//jedes Zeichen besteht aus 5 Byte bzw. Streifen
  			Puffer[Streifen]=Zeichentabelle3[y][Streifen]; 
			break;
   	}
 	Puffer[5]=0;
	_DC=1;												//Daten-Modus
	SendeDaten(Puffer,6);
}


/*
void SendeZeichen(unsigned char Zeichen)		//Zeichen auf Anzeige ausgeben
{ unsigned char Zeile;
  unsigned char Puffer[6];						//Sendepuffer der Anzeige
  
  for (Zeile=0;Zeile<=4;++Zeile)				//jedes Zeichen besteht aus 5 Byte
  Puffer[Zeile]=Pixelmuster(Zeichen,Zeile);		//aktuelles Bitmuster aus Tabelle
  Puffer[5]=0;									//zwischen Zeichen erste Reihe frei
  SendeDaten(Puffer,6);							//6 Datenbytes an Anzeige senden
}	*/

void SendeTextanLCD(rom unsigned char *Text, unsigned char Zeichenzahl)
{ 
	unsigned char i;
    for (i=0;i<Zeichenzahl;++i)				//Zeichen fr Zeichen senden
	 SendeZeichen(Text[i]);
}
